@@ -1,3 +1,3 @@
 from .base import load_excavators
 
-__all__ = ['load_excavators']
+__all__ = ["load_excavators"]
